.. _ydoc directive_2 directive_2a d2_a_dict:

``d2_a_dict``
-------------

  * ``a``: 123
  * ``b``: 567
  * ``c``: 987


this is a dict

----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.